==> evms_2.5.1.orig.tar.gz: evms-2.5.1/plugins/ha/ecellm.h <==
/*
 *
 *   (C) Copyright IBM Corp. 2002, 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * 	Module: ecellm.h
 */
#ifndef __ECELLM_H__
#define __ECELLM_H__ 1
extern void 			llm_cleanup(void);
extern void 			llm_init(void);
extern void 			llm_add(const char *, const int);
extern void 			llm_end(const char *);
extern gboolean 		llm_is_present(const char *);
extern const char * 		llm_getnodeid(int);
extern const char * 		llm_getmynodeid(void);
extern inline const int 	llm_getconfignodes(void);
extern void  			llm_getallnodes(ece_nodeid_t *);
extern char *			llm_llm2str(void);
extern void 			llm_str2llm(const char *, int );
extern inline const char * 	llm_get_clusterid(void);
extern inline gboolean 		llm_is_filled(void);
extern void 			llm_set_ece_status(const char *, gboolean);
extern gboolean 		llm_get_ece_status(const char *);
extern int 			llm_get_idx(const char *);
#endif /* __ECELLM_H__ */

==> evms_2.5.5.orig.tar.gz: evms-2.5.5/plugins/ha/ecellm.h <==
/*
 *
 *   (C) Copyright IBM Corp. 2002, 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * 	Module: ecellm.h
 */
#ifndef __ECELLM_H__
#define __ECELLM_H__ 1
extern void 			llm_cleanup(void);
extern void 			llm_init(void);
extern void 			llm_add(const char *, const int);
extern void 			llm_end(const char *);
extern gboolean 		llm_is_present(const char *);
extern const char * 		llm_getnodeid(int);
extern const char * 		llm_getmynodeid(void);
extern inline int 		llm_getconfignodes(void);
extern void  			llm_getallnodes(ece_nodeid_t *);
extern char *			llm_llm2str(void);
extern void 			llm_str2llm(const char *, int );
extern inline const char * 	llm_get_clusterid(void);
extern inline gboolean 		llm_is_filled(void);
extern void 			llm_set_ece_status(const char *, gboolean);
extern gboolean 		llm_get_ece_status(const char *);
extern int 			llm_get_idx(const char *);
#endif /* __ECELLM_H__ */
